@@ -9,8 +9,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef _LIBCUDACXX___MEMORY_UNINITIALIZED_ALGORITHMS_H
-#define _LIBCUDACXX___MEMORY_UNINITIALIZED_ALGORITHMS_H
+#ifndef _CUDA_STD___MEMORY_UNINITIALIZED_ALGORITHMS_H
+#define _CUDA_STD___MEMORY_UNINITIALIZED_ALGORITHMS_H
 
 #include <cuda/std/detail/__config>
 
@@ -51,7 +51,7 @@
 
 #include <cuda/std/__cccl/prologue.h>
 
-_LIBCUDACXX_BEGIN_NAMESPACE_STD
+_CCCL_BEGIN_NAMESPACE_CUDA_STD
 
 struct __AlwaysFalse
 {
@@ -77,7 +77,7 @@ struct __simple_rollback
   _CCCL_EXEC_CHECK_DISABLE
   _CCCL_API inline void operator()() const noexcept
   {
-    _CUDA_VSTD::__destroy(__first_, __current_);
+    ::cuda::std::__destroy(__first_, __current_);
   }
 };
 
@@ -92,11 +92,11 @@ _CCCL_API inline pair<_InputIterator, _ForwardIterator> __uninitialized_copy(
   auto __guard           = __make_exception_guard(__simple_rollback<_ForwardIterator>{__ofirst, __idx});
   for (; __ifirst != __ilast && !__stop_copying(__idx); ++__ifirst, (void) ++__idx)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType(*__ifirst);
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType(*__ifirst);
   }
   __guard.__complete();
 
-  return pair<_InputIterator, _ForwardIterator>(_CUDA_VSTD::move(__ifirst), _CUDA_VSTD::move(__idx));
+  return pair<_InputIterator, _ForwardIterator>(::cuda::std::move(__ifirst), ::cuda::std::move(__idx));
 }
 
 template <class _InputIterator, class _ForwardIterator>
@@ -104,9 +104,9 @@ _CCCL_API inline _ForwardIterator
 uninitialized_copy(_InputIterator __ifirst, _InputIterator __ilast, _ForwardIterator __ofirst)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  auto __result    = _CUDA_VSTD::__uninitialized_copy<_ValueType>(
-    _CUDA_VSTD::move(__ifirst), _CUDA_VSTD::move(__ilast), _CUDA_VSTD::move(__ofirst), __AlwaysFalse{});
-  return _CUDA_VSTD::move(__result.second);
+  auto __result    = ::cuda::std::__uninitialized_copy<_ValueType>(
+    ::cuda::std::move(__ifirst), ::cuda::std::move(__ilast), ::cuda::std::move(__ofirst), __AlwaysFalse{});
+  return ::cuda::std::move(__result.second);
 }
 
 // uninitialized_copy_n
@@ -120,20 +120,20 @@ __uninitialized_copy_n(_InputIterator __ifirst, _Size __n, _ForwardIterator __of
   auto __guard           = __make_exception_guard(__simple_rollback<_ForwardIterator>{__ofirst, __idx});
   for (; __n > 0 && !__stop_copying(__idx); ++__ifirst, (void) ++__idx, (void) --__n)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType(*__ifirst);
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType(*__ifirst);
   }
   __guard.__complete();
 
-  return pair<_InputIterator, _ForwardIterator>(_CUDA_VSTD::move(__ifirst), _CUDA_VSTD::move(__idx));
+  return pair<_InputIterator, _ForwardIterator>(::cuda::std::move(__ifirst), ::cuda::std::move(__idx));
 }
 
 template <class _InputIterator, class _Size, class _ForwardIterator>
 _CCCL_API inline _ForwardIterator uninitialized_copy_n(_InputIterator __ifirst, _Size __n, _ForwardIterator __ofirst)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  auto __result    = _CUDA_VSTD::__uninitialized_copy_n<_ValueType>(
-    _CUDA_VSTD::move(__ifirst), __n, _CUDA_VSTD::move(__ofirst), __AlwaysFalse{});
-  return _CUDA_VSTD::move(__result.second);
+  auto __result    = ::cuda::std::__uninitialized_copy_n<_ValueType>(
+    ::cuda::std::move(__ifirst), __n, ::cuda::std::move(__ofirst), __AlwaysFalse{});
+  return ::cuda::std::move(__result.second);
 }
 
 // uninitialized_fill
@@ -146,7 +146,7 @@ _CCCL_API inline _ForwardIterator __uninitialized_fill(_ForwardIterator __first,
   auto __guard           = __make_exception_guard(__simple_rollback<_ForwardIterator>{__first, __idx});
   for (; __idx != __last; ++__idx)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType(__x);
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType(__x);
   }
   __guard.__complete();
 
@@ -157,7 +157,7 @@ template <class _ForwardIterator, class _Tp>
 _CCCL_API inline void uninitialized_fill(_ForwardIterator __first, _ForwardIterator __last, const _Tp& __x)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  (void) _CUDA_VSTD::__uninitialized_fill<_ValueType>(__first, __last, __x);
+  (void) ::cuda::std::__uninitialized_fill<_ValueType>(__first, __last, __x);
 }
 
 // uninitialized_fill_n
@@ -170,7 +170,7 @@ _CCCL_API inline _ForwardIterator __uninitialized_fill_n(_ForwardIterator __firs
   auto __guard           = __make_exception_guard(__simple_rollback<_ForwardIterator>{__first, __idx});
   for (; __n > 0; ++__idx, (void) --__n)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType(__x);
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType(__x);
   }
   __guard.__complete();
 
@@ -181,7 +181,7 @@ template <class _ForwardIterator, class _Size, class _Tp>
 _CCCL_API inline _ForwardIterator uninitialized_fill_n(_ForwardIterator __first, _Size __n, const _Tp& __x)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  return _CUDA_VSTD::__uninitialized_fill_n<_ValueType>(__first, __n, __x);
+  return ::cuda::std::__uninitialized_fill_n<_ValueType>(__first, __n, __x);
 }
 
 // uninitialized_default_construct
@@ -194,7 +194,7 @@ _CCCL_API inline _ForwardIterator __uninitialized_default_construct(_ForwardIter
   auto __guard = __make_exception_guard(__simple_rollback<_ForwardIterator>{__first, __idx});
   for (; __idx != __last; ++__idx)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType;
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType;
   }
   __guard.__complete();
 
@@ -205,7 +205,8 @@ template <class _ForwardIterator>
 _CCCL_API inline void uninitialized_default_construct(_ForwardIterator __first, _ForwardIterator __last)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  (void) _CUDA_VSTD::__uninitialized_default_construct<_ValueType>(_CUDA_VSTD::move(__first), _CUDA_VSTD::move(__last));
+  (void) ::cuda::std::__uninitialized_default_construct<_ValueType>(
+    ::cuda::std::move(__first), ::cuda::std::move(__last));
 }
 
 // uninitialized_default_construct_n
@@ -218,7 +219,7 @@ _CCCL_API inline _ForwardIterator __uninitialized_default_construct_n(_ForwardIt
   auto __guard = __make_exception_guard(__simple_rollback<_ForwardIterator>{__first, __idx});
   for (; __n > 0; ++__idx, (void) --__n)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType;
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType;
   }
   __guard.__complete();
 
@@ -229,7 +230,7 @@ template <class _ForwardIterator, class _Size>
 _CCCL_API inline _ForwardIterator uninitialized_default_construct_n(_ForwardIterator __first, _Size __n)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  return _CUDA_VSTD::__uninitialized_default_construct_n<_ValueType>(_CUDA_VSTD::move(__first), __n);
+  return ::cuda::std::__uninitialized_default_construct_n<_ValueType>(::cuda::std::move(__first), __n);
 }
 
 // uninitialized_value_construct
@@ -242,7 +243,7 @@ _CCCL_API inline _ForwardIterator __uninitialized_value_construct(_ForwardIterat
   auto __guard = __make_exception_guard(__simple_rollback<_ForwardIterator>{__first, __idx});
   for (; __idx != __last; ++__idx)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType();
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType();
   }
   __guard.__complete();
 
@@ -253,7 +254,7 @@ template <class _ForwardIterator>
 _CCCL_API inline void uninitialized_value_construct(_ForwardIterator __first, _ForwardIterator __last)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  (void) _CUDA_VSTD::__uninitialized_value_construct<_ValueType>(_CUDA_VSTD::move(__first), _CUDA_VSTD::move(__last));
+  (void) ::cuda::std::__uninitialized_value_construct<_ValueType>(::cuda::std::move(__first), ::cuda::std::move(__last));
 }
 
 // uninitialized_value_construct_n
@@ -266,7 +267,7 @@ _CCCL_API inline _ForwardIterator __uninitialized_value_construct_n(_ForwardIter
   auto __guard = __make_exception_guard(__simple_rollback<_ForwardIterator>{__first, __idx});
   for (; __n > 0; ++__idx, (void) --__n)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType();
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType();
   }
   __guard.__complete();
 
@@ -277,7 +278,7 @@ template <class _ForwardIterator, class _Size>
 _CCCL_API inline _ForwardIterator uninitialized_value_construct_n(_ForwardIterator __first, _Size __n)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  return _CUDA_VSTD::__uninitialized_value_construct_n<_ValueType>(_CUDA_VSTD::move(__first), __n);
+  return ::cuda::std::__uninitialized_value_construct_n<_ValueType>(::cuda::std::move(__first), __n);
 }
 
 // uninitialized_move
@@ -296,11 +297,11 @@ _CCCL_API inline pair<_InputIterator, _ForwardIterator> __uninitialized_move(
   auto __guard = __make_exception_guard(__simple_rollback<_ForwardIterator>{__ofirst, __idx});
   for (; __ifirst != __ilast && !__stop_moving(__idx); ++__idx, (void) ++__ifirst)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType(_IterOps::__iter_move(__ifirst));
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType(_IterOps::__iter_move(__ifirst));
   }
   __guard.__complete();
 
-  return {_CUDA_VSTD::move(__ifirst), _CUDA_VSTD::move(__idx)};
+  return {::cuda::std::move(__ifirst), ::cuda::std::move(__idx)};
 }
 
 template <class _InputIterator, class _ForwardIterator>
@@ -308,9 +309,9 @@ _CCCL_API inline _ForwardIterator
 uninitialized_move(_InputIterator __ifirst, _InputIterator __ilast, _ForwardIterator __ofirst)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  auto __result    = _CUDA_VSTD::__uninitialized_move<_ValueType, _IterOps<_ClassicAlgPolicy>>(
-    _CUDA_VSTD::move(__ifirst), _CUDA_VSTD::move(__ilast), _CUDA_VSTD::move(__ofirst), __AlwaysFalse{});
-  return _CUDA_VSTD::move(__result.second);
+  auto __result    = ::cuda::std::__uninitialized_move<_ValueType, _IterOps<_ClassicAlgPolicy>>(
+    ::cuda::std::move(__ifirst), ::cuda::std::move(__ilast), ::cuda::std::move(__ofirst), __AlwaysFalse{});
+  return ::cuda::std::move(__result.second);
 }
 
 // uninitialized_move_n
@@ -324,11 +325,11 @@ __uninitialized_move_n(_InputIterator __ifirst, _Size __n, _ForwardIterator __of
   auto __guard = __make_exception_guard(__simple_rollback<_ForwardIterator>{__ofirst, __idx});
   for (; __n > 0 && !__stop_moving(__idx); ++__idx, (void) ++__ifirst, --__n)
   {
-    ::new (_CUDA_VSTD::__voidify(*__idx)) _ValueType(_IterOps::__iter_move(__ifirst));
+    ::new (::cuda::std::__voidify(*__idx)) _ValueType(_IterOps::__iter_move(__ifirst));
   }
   __guard.__complete();
 
-  return {_CUDA_VSTD::move(__ifirst), _CUDA_VSTD::move(__idx)};
+  return {::cuda::std::move(__ifirst), ::cuda::std::move(__idx)};
 }
 
 template <class _InputIterator, class _Size, class _ForwardIterator>
@@ -336,8 +337,8 @@ _CCCL_API inline pair<_InputIterator, _ForwardIterator>
 uninitialized_move_n(_InputIterator __ifirst, _Size __n, _ForwardIterator __ofirst)
 {
   using _ValueType = typename iterator_traits<_ForwardIterator>::value_type;
-  return _CUDA_VSTD::__uninitialized_move_n<_ValueType, _IterOps<_ClassicAlgPolicy>>(
-    _CUDA_VSTD::move(__ifirst), __n, _CUDA_VSTD::move(__ofirst), __AlwaysFalse{});
+  return ::cuda::std::__uninitialized_move_n<_ValueType, _IterOps<_ClassicAlgPolicy>>(
+    ::cuda::std::move(__ifirst), __n, ::cuda::std::move(__ofirst), __AlwaysFalse{});
 }
 
 // TODO: Rewrite this to iterate left to right and use reverse_iterators when calling
@@ -352,7 +353,7 @@ _CCCL_API constexpr void
 __allocator_destroy_multidimensional(_Alloc& __alloc, _BidirIter __first, _BidirIter __last) noexcept
 {
   using _ValueType = typename iterator_traits<_BidirIter>::value_type;
-  static_assert(_CCCL_TRAIT(is_same, typename allocator_traits<_Alloc>::value_type, _ValueType),
+  static_assert(is_same_v<typename allocator_traits<_Alloc>::value_type, _ValueType>,
                 "The allocator should already be rebound to the correct type");
 
   if (__first == __last)
@@ -360,7 +361,7 @@ __allocator_destroy_multidimensional(_Alloc& __alloc, _BidirIter __first, _Bidir
     return;
   }
 
-  if constexpr (_CCCL_TRAIT(is_array, _ValueType))
+  if constexpr (is_array_v<_ValueType>)
   {
     static_assert(!is_unbounded_array_v<_ValueType>,
                   "arrays of unbounded arrays don't exist, but if they did we would mess up here");
@@ -371,7 +372,7 @@ __allocator_destroy_multidimensional(_Alloc& __alloc, _BidirIter __first, _Bidir
     {
       --__last;
       auto&& __array = *__last;
-      _CUDA_VSTD::__allocator_destroy_multidimensional(__elem_alloc, __array, __array + _CCCL_TRAIT(extent, _ValueType));
+      ::cuda::std::__allocator_destroy_multidimensional(__elem_alloc, __array, __array + extent_v<_ValueType>);
     } while (__last != __first);
   }
   else
@@ -379,7 +380,7 @@ __allocator_destroy_multidimensional(_Alloc& __alloc, _BidirIter __first, _Bidir
     do
     {
       --__last;
-      allocator_traits<_Alloc>::destroy(__alloc, _CUDA_VSTD::addressof(*__last));
+      allocator_traits<_Alloc>::destroy(__alloc, ::cuda::std::addressof(*__last));
     } while (__last != __first);
   }
 }
@@ -394,10 +395,10 @@ __allocator_destroy_multidimensional(_Alloc& __alloc, _BidirIter __first, _Bidir
 template <class _Alloc, class _Tp>
 _CCCL_API constexpr void __allocator_construct_at_multidimensional(_Alloc& __alloc, _Tp* __loc)
 {
-  static_assert(_CCCL_TRAIT(is_same, typename allocator_traits<_Alloc>::value_type, _Tp),
+  static_assert(is_same_v<typename allocator_traits<_Alloc>::value_type, _Tp>,
                 "The allocator should already be rebound to the correct type");
 
-  if constexpr (_CCCL_TRAIT(is_array, _Tp))
+  if constexpr (is_array_v<_Tp>)
   {
     using _Element = remove_extent_t<_Tp>;
     __allocator_traits_rebind_t<_Alloc, _Element> __elem_alloc(__alloc);
@@ -405,13 +406,13 @@ _CCCL_API constexpr void __allocator_construct_at_multidimensional(_Alloc& __all
     _Tp& __array = *__loc;
 
     // If an exception is thrown, destroy what we have constructed so far in reverse order.
-    auto __guard = _CUDA_VSTD::__make_exception_guard([&]() {
-      _CUDA_VSTD::__allocator_destroy_multidimensional(__elem_alloc, __array, __array + __i);
+    auto __guard = ::cuda::std::__make_exception_guard([&]() {
+      ::cuda::std::__allocator_destroy_multidimensional(__elem_alloc, __array, __array + __i);
     });
 
-    for (; __i != _CCCL_TRAIT(extent, _Tp); ++__i)
+    for (; __i != extent_v<_Tp>; ++__i)
     {
-      _CUDA_VSTD::__allocator_construct_at_multidimensional(__elem_alloc, _CUDA_VSTD::addressof(__array[__i]));
+      ::cuda::std::__allocator_construct_at_multidimensional(__elem_alloc, ::cuda::std::addressof(__array[__i]));
     }
     __guard.__complete();
   }
@@ -434,12 +435,12 @@ _CCCL_API constexpr void __allocator_construct_at_multidimensional(_Alloc& __all
 template <class _Alloc, class _Tp, class _Arg>
 _CCCL_API constexpr void __allocator_construct_at_multidimensional(_Alloc& __alloc, _Tp* __loc, _Arg const& __arg)
 {
-  static_assert(_CCCL_TRAIT(is_same, typename allocator_traits<_Alloc>::value_type, _Tp),
+  static_assert(is_same_v<typename allocator_traits<_Alloc>::value_type, _Tp>,
                 "The allocator should already be rebound to the correct type");
 
-  if constexpr (_CCCL_TRAIT(is_array, _Tp))
+  if constexpr (is_array_v<_Tp>)
   {
-    static_assert(_CCCL_TRAIT(is_array, _Arg),
+    static_assert(is_array_v<_Arg>,
                   "Provided non-array initialization argument to __allocator_construct_at_multidimensional when "
                   "trying to construct an array.");
 
@@ -449,13 +450,13 @@ _CCCL_API constexpr void __allocator_construct_at_multidimensional(_Alloc& __all
     _Tp& __array = *__loc;
 
     // If an exception is thrown, destroy what we have constructed so far in reverse order.
-    auto __guard = _CUDA_VSTD::__make_exception_guard([&]() {
-      _CUDA_VSTD::__allocator_destroy_multidimensional(__elem_alloc, __array, __array + __i);
+    auto __guard = ::cuda::std::__make_exception_guard([&]() {
+      ::cuda::std::__allocator_destroy_multidimensional(__elem_alloc, __array, __array + __i);
     });
-    for (; __i != _CCCL_TRAIT(extent, _Tp); ++__i)
+    for (; __i != extent_v<_Tp>; ++__i)
     {
-      _CUDA_VSTD::__allocator_construct_at_multidimensional(
-        __elem_alloc, _CUDA_VSTD::addressof(__array[__i]), __arg[__i]);
+      ::cuda::std::__allocator_construct_at_multidimensional(
+        __elem_alloc, ::cuda::std::addressof(__array[__i]), __arg[__i]);
     }
     __guard.__complete();
   }
@@ -481,12 +482,12 @@ __uninitialized_allocator_fill_n_multidimensional(_Alloc& __alloc, _BidirIter __
   _BidirIter __begin = __it;
 
   // If an exception is thrown, destroy what we have constructed so far in reverse order.
-  auto __guard = _CUDA_VSTD::__make_exception_guard([&]() {
-    _CUDA_VSTD::__allocator_destroy_multidimensional(__value_alloc, __begin, __it);
+  auto __guard = ::cuda::std::__make_exception_guard([&]() {
+    ::cuda::std::__allocator_destroy_multidimensional(__value_alloc, __begin, __it);
   });
   for (; __n != 0; --__n, ++__it)
   {
-    _CUDA_VSTD::__allocator_construct_at_multidimensional(__value_alloc, _CUDA_VSTD::addressof(*__it), __value);
+    ::cuda::std::__allocator_construct_at_multidimensional(__value_alloc, ::cuda::std::addressof(*__it), __value);
   }
   __guard.__complete();
 }
@@ -502,12 +503,12 @@ __uninitialized_allocator_value_construct_n_multidimensional(_Alloc& __alloc, _B
   _BidirIter __begin = __it;
 
   // If an exception is thrown, destroy what we have constructed so far in reverse order.
-  auto __guard = _CUDA_VSTD::__make_exception_guard([&]() {
-    _CUDA_VSTD::__allocator_destroy_multidimensional(__value_alloc, __begin, __it);
+  auto __guard = ::cuda::std::__make_exception_guard([&]() {
+    ::cuda::std::__allocator_destroy_multidimensional(__value_alloc, __begin, __it);
   });
   for (; __n != 0; --__n, ++__it)
   {
-    _CUDA_VSTD::__allocator_construct_at_multidimensional(__value_alloc, _CUDA_VSTD::addressof(*__it));
+    ::cuda::std::__allocator_construct_at_multidimensional(__value_alloc, ::cuda::std::addressof(*__it));
   }
   __guard.__complete();
 }
@@ -518,7 +519,7 @@ _CCCL_API inline _CCCL_CONSTEXPR_CXX20 void __allocator_destroy(_Alloc& __alloc,
 {
   for (; __first != __last; ++__first)
   {
-    allocator_traits<_Alloc>::destroy(__alloc, _CUDA_VSTD::__to_address(__first));
+    allocator_traits<_Alloc>::destroy(__alloc, ::cuda::std::__to_address(__first));
   }
 }
 
@@ -534,8 +535,8 @@ public:
 
   _CCCL_API constexpr void operator()() const
   {
-    _CUDA_VSTD::__allocator_destroy(
-      __alloc_, _CUDA_VSTD::reverse_iterator<_Iter>(__last_), _CUDA_VSTD::reverse_iterator<_Iter>(__first_));
+    ::cuda::std::__allocator_destroy(
+      __alloc_, ::cuda::std::reverse_iterator<_Iter>(__last_), ::cuda::std::reverse_iterator<_Iter>(__first_));
   }
 
 private:
@@ -553,11 +554,11 @@ _CCCL_API inline _CCCL_CONSTEXPR_CXX20 _Iter2
 __uninitialized_allocator_copy_impl(_Alloc& __alloc, _Iter1 __first1, _Sent1 __last1, _Iter2 __first2)
 {
   auto __destruct_first = __first2;
-  auto __guard          = _CUDA_VSTD::__make_exception_guard(
+  auto __guard          = ::cuda::std::__make_exception_guard(
     _AllocatorDestroyRangeReverse<_Alloc, _Iter2>(__alloc, __destruct_first, __first2));
   while (__first1 != __last1)
   {
-    allocator_traits<_Alloc>::construct(__alloc, _CUDA_VSTD::__to_address(__first2), *__first1);
+    allocator_traits<_Alloc>::construct(__alloc, ::cuda::std::__to_address(__first2), *__first1);
     ++__first1;
     ++__first2;
   }
@@ -566,31 +567,28 @@ __uninitialized_allocator_copy_impl(_Alloc& __alloc, _Iter1 __first1, _Sent1 __l
 }
 
 template <class _Alloc, class _Type>
-struct __allocator_has_trivial_copy_construct : _Not<__has_construct<_Alloc, _Type*, const _Type&>>
-{};
+inline constexpr bool __allocator_has_trivial_copy_construct = !__has_construct<_Alloc, _Type*, const _Type&>;
 
 template <class _Type>
-struct __allocator_has_trivial_copy_construct<allocator<_Type>, _Type> : true_type
-{};
+inline constexpr bool __allocator_has_trivial_copy_construct<allocator<_Type>, _Type> = true;
 
-template <
-  class _Alloc,
-  class _In,
-  class _RawTypeIn = remove_const_t<_In>,
-  class _Out,
-  enable_if_t<
-    // using _RawTypeIn because of the allocator<T const> extension
-    _CCCL_TRAIT(is_trivially_copy_constructible, _RawTypeIn) && _CCCL_TRAIT(is_trivially_copy_assignable, _RawTypeIn)
-    && _CCCL_TRAIT(is_same, remove_const_t<_In>, remove_const_t<_Out>)
-    && __allocator_has_trivial_copy_construct<_Alloc, _RawTypeIn>::value>* = nullptr>
+template <class _Alloc,
+          class _In,
+          class _RawTypeIn = remove_const_t<_In>,
+          class _Out,
+          enable_if_t<
+            // using _RawTypeIn because of the allocator<T const> extension
+            is_trivially_copy_constructible_v<_RawTypeIn> && is_trivially_copy_assignable_v<_RawTypeIn>
+            && is_same_v<remove_const_t<_In>, remove_const_t<_Out>>
+            && __allocator_has_trivial_copy_construct<_Alloc, _RawTypeIn>>* = nullptr>
 _CCCL_API inline _CCCL_CONSTEXPR_CXX20 _Out*
 __uninitialized_allocator_copy_impl(_Alloc&, _In* __first1, _In* __last1, _Out* __first2)
 {
-  if (_CUDA_VSTD::is_constant_evaluated())
+  if (::cuda::std::is_constant_evaluated())
   {
     while (__first1 != __last1)
     {
-      _CUDA_VSTD::__construct_at(_CUDA_VSTD::__to_address(__first2), *__first1);
+      ::cuda::std::__construct_at(::cuda::std::__to_address(__first2), *__first1);
       ++__first1;
       ++__first2;
     }
@@ -598,7 +596,7 @@ __uninitialized_allocator_copy_impl(_Alloc&, _In* __first1, _In* __last1, _Out*
   }
   else
   {
-    return _CUDA_VSTD::copy(__first1, __last1, __first2);
+    return ::cuda::std::copy(__first1, __last1, __first2);
   }
 }
 
@@ -606,10 +604,10 @@ template <class _Alloc, class _Iter1, class _Sent1, class _Iter2>
 _CCCL_API inline _CCCL_CONSTEXPR_CXX20 _Iter2
 __uninitialized_allocator_copy(_Alloc& __alloc, _Iter1 __first1, _Sent1 __last1, _Iter2 __first2)
 {
-  auto __unwrapped_range = _CUDA_VSTD::__unwrap_range(__first1, __last1);
-  auto __result          = _CUDA_VSTD::__uninitialized_allocator_copy_impl(
-    __alloc, __unwrapped_range.first, __unwrapped_range.second, _CUDA_VSTD::__unwrap_iter(__first2));
-  return _CUDA_VSTD::__rewrap_iter(__first2, __result);
+  auto __unwrapped_range = ::cuda::std::__unwrap_range(__first1, __last1);
+  auto __result          = ::cuda::std::__uninitialized_allocator_copy_impl(
+    __alloc, __unwrapped_range.first, __unwrapped_range.second, ::cuda::std::__unwrap_iter(__first2));
+  return ::cuda::std::__rewrap_iter(__first2, __result);
 }
 
 // Move-construct the elements [__first1, __last1) into [__first2, __first2 + N)
@@ -621,18 +619,18 @@ template <class _Alloc, class _Iter1, class _Sent1, class _Iter2>
 _CCCL_API inline _CCCL_CONSTEXPR_CXX20 _Iter2
 __uninitialized_allocator_move_if_noexcept(_Alloc& __alloc, _Iter1 __first1, _Sent1 __last1, _Iter2 __first2)
 {
-  static_assert(__is_cpp17_move_insertable<_Alloc>::value,
+  static_assert(__is_cpp17_move_insertable<_Alloc>,
                 "The specified type does not meet the requirements of Cpp17MoveInsertable");
   auto __destruct_first = __first2;
-  auto __guard          = _CUDA_VSTD::__make_exception_guard(
+  auto __guard          = ::cuda::std::__make_exception_guard(
     _AllocatorDestroyRangeReverse<_Alloc, _Iter2>(__alloc, __destruct_first, __first2));
   while (__first1 != __last1)
   {
 #if _CCCL_HAS_EXCEPTIONS()
     allocator_traits<_Alloc>::construct(
-      __alloc, _CUDA_VSTD::__to_address(__first2), _CUDA_VSTD::move_if_noexcept(*__first1));
+      __alloc, ::cuda::std::__to_address(__first2), ::cuda::std::move_if_noexcept(*__first1));
 #else // ^^^ _CCCL_HAS_EXCEPTIONS() ^^^ / vvv !_CCCL_HAS_EXCEPTIONS() vvv
-    allocator_traits<_Alloc>::construct(__alloc, _CUDA_VSTD::__to_address(__first2), _CUDA_VSTD::move(*__first1));
+    allocator_traits<_Alloc>::construct(__alloc, ::cuda::std::__to_address(__first2), ::cuda::std::move(*__first1));
 #endif // !_CCCL_HAS_EXCEPTIONS()
     ++__first1;
     ++__first2;
@@ -642,29 +640,26 @@ __uninitialized_allocator_move_if_noexcept(_Alloc& __alloc, _Iter1 __first1, _Se
 }
 
 template <class _Alloc, class _Type>
-struct __allocator_has_trivial_move_construct : _Not<__has_construct<_Alloc, _Type*, _Type&&>>
-{};
+inline constexpr bool __allocator_has_trivial_move_construct = !__has_construct<_Alloc, _Type*, _Type&&>;
 
 template <class _Type>
-struct __allocator_has_trivial_move_construct<allocator<_Type>, _Type> : true_type
-{};
+inline constexpr bool __allocator_has_trivial_move_construct<allocator<_Type>, _Type> = true;
 
 #if !_CCCL_COMPILER(GCC)
 template <class _Alloc,
           class _Iter1,
           class _Iter2,
           class _Type = typename iterator_traits<_Iter1>::value_type,
-          class       = enable_if_t<_CCCL_TRAIT(is_trivially_move_constructible, _Type)
-                                    && _CCCL_TRAIT(is_trivially_move_assignable, _Type)
-                                    && __allocator_has_trivial_move_construct<_Alloc, _Type>::value>>
+          class       = enable_if_t<is_trivially_move_constructible_v<_Type> && is_trivially_move_assignable_v<_Type>
+                                    && __allocator_has_trivial_move_construct<_Alloc, _Type>>>
 _CCCL_API inline _CCCL_CONSTEXPR_CXX20 _Iter2
 __uninitialized_allocator_move_if_noexcept(_Alloc&, _Iter1 __first1, _Iter1 __last1, _Iter2 __first2)
 {
-  if (_CUDA_VSTD::is_constant_evaluated())
+  if (::cuda::std::is_constant_evaluated())
   {
     while (__first1 != __last1)
     {
-      _CUDA_VSTD::__construct_at(_CUDA_VSTD::__to_address(__first2), _CUDA_VSTD::move(*__first1));
+      ::cuda::std::__construct_at(::cuda::std::__to_address(__first2), ::cuda::std::move(*__first1));
       ++__first1;
       ++__first2;
     }
@@ -672,13 +667,13 @@ __uninitialized_allocator_move_if_noexcept(_Alloc&, _Iter1 __first1, _Iter1 __la
   }
   else
   {
-    return _CUDA_VSTD::move(__first1, __last1, __first2);
+    return ::cuda::std::move(__first1, __last1, __first2);
   }
 }
 #endif // !_CCCL_COMPILER(GCC)
 
-_LIBCUDACXX_END_NAMESPACE_STD
+_CCCL_END_NAMESPACE_CUDA_STD
 
 #include <cuda/std/__cccl/epilogue.h>
 
-#endif // _LIBCUDACXX___MEMORY_UNINITIALIZED_ALGORITHMS_H
+#endif // _CUDA_STD___MEMORY_UNINITIALIZED_ALGORITHMS_H
