@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef _LIBCUDACXX___TYPE_TRAITS_LAZY_H
-#define _LIBCUDACXX___TYPE_TRAITS_LAZY_H
+#ifndef _CUDA_STD___TYPE_TRAITS_LAZY_H
+#define _CUDA_STD___TYPE_TRAITS_LAZY_H
 
 #include <cuda/std/detail/__config>
 
@@ -22,14 +22,14 @@
 
 #include <cuda/std/__cccl/prologue.h>
 
-_LIBCUDACXX_BEGIN_NAMESPACE_STD
+_CCCL_BEGIN_NAMESPACE_CUDA_STD
 
 template <template <class...> class _Func, class... _Args>
 struct _Lazy : _Func<_Args...>
 {};
 
-_LIBCUDACXX_END_NAMESPACE_STD
+_CCCL_END_NAMESPACE_CUDA_STD
 
 #include <cuda/std/__cccl/epilogue.h>
 
-#endif // _LIBCUDACXX___TYPE_TRAITS_LAZY_H
+#endif // _CUDA_STD___TYPE_TRAITS_LAZY_H
